@@ -1,13 +1,9 @@
-from __future__ import unicode_literals
-
 from mopidy import models
 
 import pytest
-
 from mopidy_podcast import feeds
 
-
-XML = b"""<?xml version="1.0" encoding="UTF-8"?>
+XML = """<?xml version="1.0" encoding="UTF-8"?>
 <opml version="2.0">
   <head>
     <title>example.opml</title>
@@ -38,11 +34,11 @@ XML = b"""<?xml version="1.0" encoding="UTF-8"?>
 
 @pytest.fixture
 def opml():
-    from StringIO import StringIO
+    from io import StringIO
 
     class StringSource(StringIO):
         def geturl(self):
-            return 'http://example.com/example.opml'
+            return "http://example.com/example.opml"
 
     return StringSource(XML)
 
@@ -51,26 +47,26 @@ def test_items(opml):
     feed = feeds.parse(opml)
     assert list(feed.items()) == [
         models.Ref.album(
-            uri='podcast+http://example.com/podcast1.rss', name='Podcast'
+            uri="podcast+http://example.com/podcast1.rss", name="Podcast"
         ),
         models.Ref.album(
-            uri='podcast+http://example.com/podcast2.xml', name='Podcast'
+            uri="podcast+http://example.com/podcast2.xml", name="Podcast"
         ),
         models.Ref.album(
-            uri='podcast+http://example.com/podcast3', name='Podcast'
+            uri="podcast+http://example.com/podcast3", name="Podcast"
         ),
         models.Ref.directory(
-            uri='podcast+http://example.com/directory1', name='Directory'
+            uri="podcast+http://example.com/directory1", name="Directory"
         ),
         models.Ref.directory(
-            uri='podcast+http://example.com/directory2.opml', name='Directory'
+            uri="podcast+http://example.com/directory2.opml", name="Directory"
         ),
         models.Ref.album(
-            uri='podcast+http://example.com/podcast4.xml', name='Podcast'
+            uri="podcast+http://example.com/podcast4.xml", name="Podcast"
         ),
         models.Ref.album(
-            uri='podcast+http://example.com/podcast5.xml', name='PODCAST'
-        )
+            uri="podcast+http://example.com/podcast5.xml", name="PODCAST"
+        ),
     ]
 
 
